import { Subject, Resource } from "../types";
import { PermissionResolver } from "./PermissionResolver";

export function flattenPermissionsForSubject(
  resolver: PermissionResolver,
  subject: Subject,
  resource: Resource
): string[] {
  const allowed: string[] = [];

  const actions = new Set<string>();

  // Collect all unique actions applicable to this resource type
  for (const rule of resolver["rules"]) {
    if (rule.resource === resource.type) {
      actions.add(rule.action);
    }
  }

  for (const action of actions) {
    if (resolver.can(subject, resource, action)) {
      allowed.push(`${resource.type}:${action}`);
    }
  }

  return allowed;
}
